@@ -1,15 +1,14 @@
-## no critic('RequireFilenameMatchesPackage','strict')
+## no critic('RequireFilenameMatchesPackage')
 package Math::Prime::FastSieve;
-our $VERSION = '0.03';
+use strict;
+use warnings;
+
+our $VERSION = '0.04';
 
 =head1 NAME
 
 Alt::Math::Prime::FastSieve::Inline - Alternate Math::Prime::FastSieve using Inline::Module
 
-=head1 VERSION
-
-Version 0.01
-
 =head1 SYNOPSIS
 
     > cpanm Alt::Math::Prime::FastSieve::Inline
